@@ -18,6 +18,7 @@ def set_config(config):
 class TCellAgentConfiguration(object):
     def __init__(self):
         self.enabled = True  # DEFAULT
+        self.disabled_instrumentation = set()
 
     def load_ffi_config(self, config):
         first_app = config.get("applications", {}).get("first", {})
@@ -26,7 +27,7 @@ class TCellAgentConfiguration(object):
         self.reverse_proxy = first_app.get("reverse_proxy")
         self.reverse_proxy_ip_address_header = first_app.get("reverse_proxy_ip_address_header")
 
-        self.disabled_instrumentation = config.get('disabled_instrumentation')
+        self.disabled_instrumentation = set(config.get('disabled_instrumentation'))
         self.logging_options = config.get("log_config")
         self.fetch_policies_from_tcell = config.get("update_policy")
 
