@@ -34,7 +34,6 @@ def _instrument(run_dlp_instrumentation):
     old_load_middleware = BaseHandler.load_middleware
 
     def load_middleware(*args, **kwargs):
-        get_module_logger(__name__).info("Adding middleware")
         insert_middleware(
             "tcell_agent.instrumentation.djangoinst.middleware.body_filter_middleware.BodyFilterMiddleware")
         insert_middleware(
@@ -83,5 +82,7 @@ def instrument_django():
     except ImportError:
         pass
     except Exception as e:
-        get_module_logger(__name__).debug("Could not instrument django: {e}".format(e=e))
-        get_module_logger(__name__).exception(e)
+        LOGGER = get_module_logger(__name__)
+        if LOGGER:
+            LOGGER.debug("Could not instrument django: {e}".format(e=e))
+            LOGGER.exception(e)
