@@ -1,5 +1,5 @@
 from tcell_agent.global_state import get_default_charset
-from tcell_agent.instrumentation.better_ip_address import better_ip_address, tcell_get_host
+from tcell_agent.instrumentation.better_ip_address import tcell_get_host, get_remote_address, get_reverse_proxy_header
 from tcell_agent.instrumentation.context import TCellInstrumentationContext
 from tcell_agent.instrumentation.decorators import catches_generic_exception
 from tcell_agent.instrumentation.djangoinst.models import \
@@ -13,7 +13,8 @@ def initialize_tcell_context(request):
     request._tcell_context = TCellInstrumentationContext()
     request._tcell_context.referrer = request.META.get("HTTP_REFERER")
     request._tcell_context.user_agent = request.META.get("HTTP_USER_AGENT")
-    request._tcell_context.remote_address = better_ip_address(request.META)
+    request._tcell_context.remote_address = get_remote_address(request.META)
+    request._tcell_context.reverse_proxy_header_value = get_reverse_proxy_header(request.META)
     request._tcell_context.method = request.method
     request._tcell_context.path = request.path
     request._tcell_context.fullpath = tcell_get_full_path(request)
@@ -24,6 +25,7 @@ def initialize_tcell_context(request):
 def get_appsensor_meta(request):
     appsensor_meta = request._tcell_context.appsensor_meta
     appsensor_meta.remote_address = request._tcell_context.remote_address
+    appsensor_meta.reverse_proxy_header_value = request._tcell_context.reverse_proxy_header_value
     appsensor_meta.method = request._tcell_context.method
     appsensor_meta.user_agent_str = request._tcell_context.user_agent
     appsensor_meta.location = request._tcell_context.uri
