@@ -20,10 +20,10 @@ class TCellDjangoRequest(object):
         self.filenames_dict = normalize_filenames(request.FILES)
 
     def is_multipart(self):
-        self.content_type.startswith("multipart/form-data")
+        return self.content_type.startswith("multipart/form-data")
 
     def is_json(self):
-        self.content_type.startswith('application/json')
+        return self.content_type.startswith('application/json')
 
 
 def normalize_filenames(files_multi_dict):
