@@ -6,6 +6,7 @@ from tcell_agent.agent import TCellAgent
 from tcell_agent.instrumentation.utils import get_tcell_context
 from tcell_agent.policies.policy_types import PolicyTypes
 
+from tcell_agent.instrumentation.decorators import catches_generic_exception
 
 def get_native_file_mode_from_str(mode):
     if '+' in mode:
@@ -27,6 +28,16 @@ def get_native_file_mode_from_flags(flags):
     return 'Read'
 
 
+@catches_generic_exception(__name__,
+                           "Error in extracting mode from file open call, assumed 'Read' as default.",
+                           return_value="Read")
+def get_native_file_mode(mode):
+    if type(mode) == str:
+        return get_native_file_mode_from_str(mode)
+
+    return get_native_file_mode_from_flags(mode)
+
+
 def should_block_file_open(file_path, mode, opener_class):
     if not file_path:
         return False
