@@ -1,7 +1,9 @@
 from __future__ import print_function
 
-from tcell_agent.global_state import needs_instrumentation, set_has_been_instrumented
+from tcell_agent.global_state import needs_instrumentation, set_has_been_instrumented, need_after_agent_started_instrumentation, set_after_agent_started_instrumentation
 from tcell_agent.version import VERSION
+from tcell_agent.instrumentation.cmdi import instrument_commands
+from tcell_agent.instrumentation.lfi import instrument_file_open
 
 
 def run_instrumentations():
@@ -20,17 +22,18 @@ def run_instrumentations():
         from tcell_agent.instrumentation.hooks.login_fraud import instrument_tcell_hooks
         instrument_tcell_hooks()
 
-        from tcell_agent.instrumentation.cmdi import instrument_commands
-        instrument_commands()
-
-        from tcell_agent.instrumentation.lfi import instrument_file_open
-        instrument_file_open()
-
         return True
 
     return False
 
 
+def instrument_lfi_os():
+    if need_after_agent_started_instrumentation():
+        set_after_agent_started_instrumentation()
+        instrument_commands()
+        instrument_file_open()
+
+
 def instrument():
     """
     This function could potentially be called multiple times if
