@@ -7,6 +7,7 @@ class EmptyContext(object):
         self.session_id = None
         self.user_id = None
         self.uri = None
+        self.reverse_proxy_header_value = None
 
 
 class CommandContext(dict):
@@ -24,3 +25,4 @@ class CommandContext(dict):
         self["session_id"] = tcell_context.session_id
         self["user_id"] = tcell_context.user_id
         self["full_uri"] = tcell_context.uri
+        self["reverse_proxy_header_value"] = tcell_context.reverse_proxy_header_value
