@@ -162,7 +162,8 @@ class NativeAgent(object):
                        session_id,
                        user_id,
                        user_agent,
-                       remote_address):
+                       remote_address,
+                       reverse_proxy_header_value):
         if request_time:
             message = {
                 "elapsed_time": request_time,
@@ -170,7 +171,8 @@ class NativeAgent(object):
                 "session_id": session_id,
                 "user_id": user_id,
                 "user_agent": user_agent,
-                "remote_address": remote_address
+                "remote_address": remote_address,
+                "reverse_proxy_header_value": reverse_proxy_header_value
             }
             return self.call_with_one_argument(
                 message=message,
@@ -218,11 +220,11 @@ class PlaceholderNativeAgent(NativeAgent):
         self.logger = PythonLogger()
 
 
-def create_native_agent():
+def create_native_agent(framework_details):
     if get_native_lib():
         caller = NativeCaller(native_method_name="create_agent",
                               bytes_to_allocate=1024 * 8)
-        caller.append_parameter(AgentConfig())
+        caller.append_parameter(AgentConfig(framework_details))
         response = caller.execute()
         if response.get_errors():
             logger = PythonLogger()
