@@ -2,9 +2,7 @@ from __future__ import print_function
 
 import unittest
 
-from mock import call, patch
-
-from django import get_version
+from mock import patch
 
 from tcell_agent.agent import TCellAgent
 from tcell_agent.instrumentation.djangoinst.check_agent_startup import \
@@ -41,25 +39,13 @@ class CheckAgentStartupTest(unittest.TestCase):
                     as patched_update_default_charset:
                 with patch("tcell_agent.instrumentation.djangoinst.check_agent_startup.start_agent",
                            return_value=True) as patched_start_agent:
-                    with patch.object(TCellAgent, "send", return_value=None) as patched_send:
-                        with patch("tcell_agent.instrumentation.djangoinst.check_agent_startup.send_django_setting_events",
-                                   return_value=True) as patched_send_django_setting_events:
-                            ensure_agent_started()
-                            self.assertTrue(patched_has_agent_started.called)
-                            self.assertTrue(patched_update_default_charset.called)
-                            self.assertTrue(patched_start_agent.called)
-                            self.assertTrue(patched_send_django_setting_events.called)
-                            self.assertTrue(patched_send.called)
-
-                            patched_send.assert_has_calls(
-                                [
-                                    call({
-                                        "event_type": "server_agent_details",
-                                        "app_framework": "Django",
-                                        "app_framework_version": get_version()
-                                    })
-                                ]
-                            )
+                    with patch("tcell_agent.instrumentation.djangoinst.check_agent_startup.send_django_setting_events",
+                               return_value=True) as patched_send_django_setting_events:
+                        ensure_agent_started()
+                        self.assertTrue(patched_has_agent_started.called)
+                        self.assertTrue(patched_update_default_charset.called)
+                        self.assertTrue(patched_start_agent.called)
+                        self.assertTrue(patched_send_django_setting_events.called)
 
     def test_other_thread_has_started_agent_start_agent(self):
         with patch("tcell_agent.instrumentation.djangoinst.check_agent_startup.has_agent_started",
