@@ -2,6 +2,7 @@
 
 from __future__ import print_function
 
+from django import get_version
 from django.test import TestCase
 from django.test.client import RequestFactory
 from django.http import HttpResponse
@@ -57,10 +58,16 @@ class BodyFilterMiddlewareTest(TestCase):
     def setUp(self):
         settings.ALLOWED_HOSTS = ["testserver", "test.tcell.io"]
 
-        self.grm = GlobalRequestMiddleware()
-        self.aam = AfterAuthMiddleware()
-        self.cmw = CommonMiddleware()
-        self.bfm = BodyFilterMiddleware()
+        def get_response(): pass
+
+        self.grm = GlobalRequestMiddleware(get_response)
+        self.aam = AfterAuthMiddleware(get_response)
+        self.bfm = BodyFilterMiddleware(get_response)
+
+        if get_version().split(".")[0] == "1":
+            self.cmw = CommonMiddleware()
+        else:
+            self.cmw = CommonMiddleware(get_response)
 
         request_factory = RequestFactory()
         self.request = request_factory.get("http://test.tcell.io/hello/")
@@ -72,7 +79,7 @@ class BodyFilterMiddlewareTest(TestCase):
         TCellAgent.tCell_agent = TCellAgent()
         with patch("tcell_agent.agent.create_native_agent") as patched_create_native_agent:
             patched_create_native_agent.return_value = NativeAgentBuilder()
-            TCellAgent.tCell_agent.create_native_agent()
+            TCellAgent.tCell_agent.create_native_agent({})
 
     def tearDown(self):
         free_native_agent(TCellAgent.tCell_agent.native_agent.agent_ptr)
