@@ -2,6 +2,7 @@
 from __future__ import print_function
 
 from tcell_agent.instrumentation.djangoinst.compatability import DJANGO_VERSION
+from django import get_version
 
 if DJANGO_VERSION[:2] not in [(1, 5), (1, 6)]:
     import logging
@@ -75,12 +76,18 @@ if DJANGO_VERSION[:2] not in [(1, 5), (1, 6)]:
             settings.ALLOWED_HOSTS = ["testserver", "test.tcell.io"]
             settings.ROOT_URLCONF = "tcell_agent.tests.instrumentation.djangoinst.middleware.test_urls"
 
-            self.grm = GlobalRequestMiddleware()
-            self.aam = AfterAuthMiddleware()
-            self.cm = CommonMiddleware()
-            self.bfm = BodyFilterMiddleware()
-            self.data_exposure_middleware = TCellDataExposureMiddleware()
-            self.tcell_last_middleware = TCellLastMiddleware()
+            def get_response(): pass
+
+            self.grm = GlobalRequestMiddleware(get_response)
+            self.aam = AfterAuthMiddleware(get_response)
+            self.bfm = BodyFilterMiddleware(get_response)
+            self.data_exposure_middleware = TCellDataExposureMiddleware(get_response)
+            self.tcell_last_middleware = TCellLastMiddleware(get_response)
+
+            if get_version().split(".")[0] == "1":
+                self.cm = CommonMiddleware()
+            else:
+                self.cm = CommonMiddleware(get_response)
 
             self.rf = RequestFactory()
 
