@@ -132,7 +132,7 @@ if sys.version_info >= (3, 0):
                     "HTTP_HOST": "http://192.168.99.1",
                     "HTTP_USER_AGENT": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_6) ...",
                     "HTTP_REFERER": "http://192.168.99.100:3000/"})
-            django_request.get_full_path = MagicMock(return_value="/users/auth/doorkeeper/callbackuri")
+            django_request.build_absolute_uri = MagicMock(return_value="http://127.0.0.1:8000/login")
 
             with patch.object(self.login_policy, "report_login_success", return_value=None) \
                     as patched_report_login_success:
@@ -153,7 +153,7 @@ if sys.version_info >= (3, 0):
                     self.assertEqual(kwargs["tcell_context"].user_agent, "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_6) ...")
                     self.assertEqual(kwargs["tcell_context"].remote_address, "192.168.99.1")
                     self.assertEqual(kwargs["tcell_context"].session_id, "124KDJFL3234")
-                    self.assertEqual(kwargs["tcell_context"].fullpath, "/users/auth/doorkeeper/callbackuri")
+                    self.assertEqual(kwargs["tcell_context"].fullpath, "http://127.0.0.1:8000/login")
                     self.assertEqual(kwargs["tcell_context"].referrer, "http://192.168.99.100:3000/")
 
         def test_django_login_failure_hooks(self):
@@ -164,7 +164,7 @@ if sys.version_info >= (3, 0):
                     "HTTP_HOST": "http://192.168.99.1",
                     "HTTP_USER_AGENT": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_6) ...",
                     "HTTP_REFERER": "http://192.168.99.100:3000/"})
-            django_request.get_full_path = MagicMock(return_value="/users/auth/doorkeeper/callbackuri")
+            django_request.build_absolute_uri = MagicMock(return_value="http://127.0.0.1:8000/login")
 
             with patch.object(self.login_policy, "report_login_failure", return_value=None) \
                     as patched_report_login_failure:
@@ -188,7 +188,7 @@ if sys.version_info >= (3, 0):
                     self.assertEqual(kwargs["tcell_context"].user_agent, "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_11_6) ...")
                     self.assertEqual(kwargs["tcell_context"].remote_address, "192.168.99.1")
                     self.assertEqual(kwargs["tcell_context"].session_id, "124KDJFL3234")
-                    self.assertEqual(kwargs["tcell_context"].fullpath, "/users/auth/doorkeeper/callbackuri")
+                    self.assertEqual(kwargs["tcell_context"].fullpath, "http://127.0.0.1:8000/login")
                     self.assertEqual(kwargs["tcell_context"].referrer, "http://192.168.99.100:3000/")
 
         def test_flask_login_success_hooks(self):
