@@ -4,7 +4,7 @@ import _io
 import io
 import os
 import unittest
-
+import sys
 import pytest
 
 from tcell_agent.instrumentation.lfi import instrument_file_open
@@ -97,6 +97,11 @@ class Py2LFIInstrumentationTests(unittest.TestCase):
 @pytest.mark.usefixtures('disable_block')
 class Py3LFIInstrumentationTests(unittest.TestCase):
     def setUp(self):
+        if sys.version_info < (3, 10):
+            self.call_count = 2
+        else:
+            self.call_count = 1
+
         ConfigurationBuilder().set_config()
         instrument_file_open()
 
@@ -105,10 +110,10 @@ class Py3LFIInstrumentationTests(unittest.TestCase):
 
     def test_pathlib_open_function_is_blocking_twice(self):
         # since `pathlib.Path.open` is using both `io.open` and `os.open` we
-        # will receive two events
+        # will receive two events. In 3.10.0a7+ builds, it only uses `os.open`
         with pathlib.Path(test_file).open('r') as f:
             f.read()
-        assert self.block.call_count == 2
+        assert self.block.call_count == self.call_count
 
     def test_builtin_open_function_has_correct_wrapper(self):
         assert open.__tcell_instrumentation__new_method__.__name__ == 'py3_open_wrapper'
