@@ -11,17 +11,21 @@ class PatchesPolicyTest(unittest.TestCase):
     def setUp(self):
         self.native_agent = NativeAgentBuilder()
 
-    def tearDown(self):
-        free_native_agent(self.native_agent.agent_ptr)
+        self.ip_groups_rsp = self.native_agent.update_policies({
+            "iplists": {
+                "policy_id": "1234",
+                "version": 1,
+                "enabled": True,
+                "lists": {
+                    "ipgroups#test": ["1.1.1.1"]
+                }
+            }
+        })
 
-    def test_classname(self):
-        self.assertEqual(PatchesPolicy.api_identifier, "patches")
-
-    def test_enabled_ip_blocking_block_request_with_none_ip(self):
-        policies_rsp = self.native_agent.update_policies({
+        self.policies_rsp = self.native_agent.update_policies({
             "patches": {
                 "policy_id": "policy_id",
-                "version": 2,
+                "version": 1,
                 "data": {
                     "rules": [{
                         "id": "blocked-ips-rule",
@@ -32,10 +36,7 @@ class PatchesPolicyTest(unittest.TestCase):
                         "matches": [{
                             "all": [],
                             "any": [{
-                                "ips": [{
-                                    "type": "IP",
-                                    "values": ["1.1.1.1"]
-                                }]
+                                "ips": ["ipgroups#test"]
                             }]
                         }]
                     }]
@@ -43,7 +44,14 @@ class PatchesPolicyTest(unittest.TestCase):
             }
         })
 
-        policy = PatchesPolicy(self.native_agent, policies_rsp["enablements"], None)
+    def tearDown(self):
+        free_native_agent(self.native_agent.agent_ptr)
+
+    def test_classname(self):
+        self.assertEqual(PatchesPolicy.api_identifier, "patches")
+
+    def test_enabled_ip_blocking_block_request_with_none_ip(self):
+        policy = PatchesPolicy(self.native_agent, self.policies_rsp["enablements"], None)
         appsensor_meta = AppSensorMetaBuilder().update_attribute(
             "remote_address", None
         ) .build()
@@ -60,32 +68,7 @@ class PatchesPolicyTest(unittest.TestCase):
         mock.assert_not_called()
 
     def test_enabled_ip_blocking_block_request_with_empty_ip(self):
-        policies_rsp = self.native_agent.update_policies({
-            "patches": {
-                "policy_id": "policy_id",
-                "version": 2,
-                "data": {
-                    "rules": [{
-                        "id": "blocked-ips-rule",
-                        "title": "Blocked ips rule",
-                        "action": "BlockIf",
-                        "destinations": {"check_equals": [{"path": "*"}]},
-                        "ignore": [],
-                        "matches": [{
-                            "all": [],
-                            "any": [{
-                                "ips": [{
-                                    "type": "IP",
-                                    "values": ["1.1.1.1"]
-                                }]
-                            }]
-                        }]
-                    }]
-                }
-            }
-        })
-
-        policy = PatchesPolicy(self.native_agent, policies_rsp["enablements"], None)
+        policy = PatchesPolicy(self.native_agent, self.policies_rsp["enablements"], None)
         appsensor_meta = AppSensorMetaBuilder().update_attribute(
             "remote_address", ""
         ) .build()
@@ -102,32 +85,8 @@ class PatchesPolicyTest(unittest.TestCase):
         mock.assert_not_called()
 
     def test_enabled_ip_blocking_block_request_with_blocked_ip(self):
-        policies_rsp = self.native_agent.update_policies({
-            "patches": {
-                "policy_id": "policy_id",
-                "version": 2,
-                "data": {
-                    "rules": [{
-                        "id": "blocked-ips-rule",
-                        "title": "Blocked ips rule",
-                        "action": "BlockIf",
-                        "destinations": {"check_equals": [{"path": "*"}]},
-                        "ignore": [],
-                        "matches": [{
-                            "all": [],
-                            "any": [{
-                                "ips": [{
-                                    "type": "IP",
-                                    "values": ["1.1.1.1"]
-                                }]
-                            }]
-                        }]
-                    }]
-                }
-            }
-        })
+        policy = PatchesPolicy(self.native_agent, self.policies_rsp["enablements"], None)
 
-        policy = PatchesPolicy(self.native_agent, policies_rsp["enablements"], None)
         appsensor_meta = AppSensorMetaBuilder().update_attribute(
             "remote_address", "1.1.1.1"
         ) .build()
@@ -145,32 +104,7 @@ class PatchesPolicyTest(unittest.TestCase):
         mock.assert_not_called()
 
     def test_enabled_ip_blocking_block_request_with_non_blocked_ip(self):
-        policies_rsp = self.native_agent.update_policies({
-            "patches": {
-                "policy_id": "policy_id",
-                "version": 2,
-                "data": {
-                    "rules": [{
-                        "id": "blocked-ips-rule",
-                        "title": "Blocked ips rule",
-                        "action": "BlockIf",
-                        "destinations": {"check_equals": [{"path": "*"}]},
-                        "ignore": [],
-                        "matches": [{
-                            "all": [],
-                            "any": [{
-                                "ips": [{
-                                    "type": "IP",
-                                    "values": ["1.1.1.1"]
-                                }]
-                            }]
-                        }]
-                    }]
-                }
-            }
-        })
-
-        policy = PatchesPolicy(self.native_agent, policies_rsp["enablements"], None)
+        policy = PatchesPolicy(self.native_agent, self.policies_rsp["enablements"], None)
         appsensor_meta = AppSensorMetaBuilder().update_attribute(
             "remote_address", "2.2.2.2"
         ) .build()
